logarithm_big_int library
Use this library to get the bigInt logarithm value given the value to be calculated and the base of the logarithm
Use this library to get the bigInt logarithm value given the value to be calculated and the base of the logarithm